==> wxWidgets-3.0.4.tar.bz2: wxWidgets-3.0.4/docs/doxygen/mainpages/manual.h <==
/////////////////////////////////////////////////////////////////////////////
// Name:        main.h
// Purpose:     Main page of the Doxygen manual
// Author:      wxWidgets team
// Licence:     wxWindows licence
/////////////////////////////////////////////////////////////////////////////

/**

@mainpage Documentation

@image html main_wxlogo.png

@author Julian Smart, Vadim Zeitlin, Robin Dunn, Stefan Csomor,
        Bryan Petty, Francesco Montorsi, Robert Roebling et al

@date March 8, 2018

@n

Welcome to wxWidgets, a stable and powerful open source framework for
developing native cross-platform GUI applications in C++!

@n

If you are new to wxWidgets, please start with the @subpage page_introduction
"introduction" and follow with the @subpage page_topics "programming guides",
with maybe a look at @subpage page_samples "the samples" as you go. If you are
already familiar with wxWidgets, please read about @subpage
overview_changes_since28 "the changes" in the latest version compared to 2.8
series. And you can also follow the links in the reference section or jump
directly to the <a href="classes.html">alphabetical list of classes</a>
to find out more about the topic you are interested in.

@section manual_user User Manual

@li @subpage page_introduction
@li @subpage page_topics
@li @subpage page_libs
@li @subpage page_class_cat
@li @subpage overview_changes_since28

@section manual_reference Reference

@li @subpage group_class
@li @subpage group_funcmacro
@li @subpage page_constants

@section manual_misc Other Information

@li @subpage page_samples
@li @subpage page_utils
@li @subpage page_translations
@li @subpage page_multiplatform
@li @subpage page_copyright

*/

==> wxWidgets-3.1.0.tar.bz2: wxWidgets-3.1.0/docs/doxygen/mainpages/manual.h <==
/////////////////////////////////////////////////////////////////////////////
// Name:        main.h
// Purpose:     Main page of the Doxygen manual
// Author:      wxWidgets team
// Licence:     wxWindows licence
/////////////////////////////////////////////////////////////////////////////

/**

@mainpage Documentation

@image html main_wxlogo.png

@author Julian Smart, Vadim Zeitlin, Robin Dunn, Stefan Csomor,
        Bryan Petty, Francesco Montorsi, Robert Roebling et al

@date February 29, 2016

@n

Welcome to wxWidgets, a stable and powerful open source framework for
developing native cross-platform GUI applications in C++!

@n

If you are new to wxWidgets, please start with the @subpage page_introduction
and follow with the @subpage page_topics, with maybe a look at
@subpage page_samples as you go. If you are already familiar with wxWidgets,
please read about @subpage overview_changes_since28 "the changes" in the latest
version compared to 2.8 series. And you can also follow the links in the
reference section or jump directly to the
<a href="classes.html">alphabetical list of classes</a> to find out more about
the topic you are interested in.

@section manual_user User Manual

@li @subpage page_introduction
@li @subpage page_topics
@li @subpage page_libs
@li @subpage page_class_cat
@li @subpage overview_changes_since28

@section manual_reference Reference

@li @subpage group_class
@li @subpage group_funcmacro
@li @subpage page_constants

@section manual_misc Other Information

@li @subpage page_samples
@li @subpage page_utils
@li @subpage page_translations
@li @subpage page_multiplatform
@li @subpage page_copyright

*/
